Generate a list of models with one or more free parameter dropped (fixed to zero).
get_drop(
sem_out,
must_drop = NULL,
must_not_drop = NULL,
loadings_to_exclude = c("single", "none", "all"),
df_change = 1,
model_id = NA,
keep_correct_df_change = TRUE,
remove_duplicated = TRUE,
progress = FALSE
)An object of the class
partables, a named list of parameter
tables, each of them to be used by
lavaan::lavaan() or update()
for fitting a model with the added parameters.
The original model, which is the output from an structural equation modeling function. Currently support lavaan::lavaan objects only.
A character vector
of parameters, named in
lavaan::lavaan() style (e.g.,
"y ~ x"), that must be included.
Default is NULL.
A character
vector of parameters, named in
lavaan::lavaan() style (e.g.,
"x1 ~~ x1"), that must not be
included. Default is NULL.
Whether factor loadings
will be excluded. If "single",
then only "single" loadings (an indicator
loads on only one latent factor)
will be excluded. If "all", then
all factor loadings will be excluded.
If "none", then no loadings will
be excluded. Be careful when using
"none" because the models may not
make sense. The settings in must_drop
and must_not_drop will override this
argument.
How many degrees of freedom away in the list. All models with df change less than or equal to this number will be included, taking into account requirements set by other arguments. Default is 1.
The identification
number of the starting model.
Default is NA, no identification
number.
Keep only models with actual df change equal to expected df change.
If TRUE,
the default, duplicated models are
removed.
Whether a progress
bar will be displayed, implemented
by the pbapply package. Default
is FALSE.
Shu Fai Cheung https://orcid.org/0000-0002-9871-9448
It generates a list of models with one or more free parameters dropped, that is, fixed to zero (with degrees of freedom, df, increases by one or more).
All free parameters are included in the pool of candidates, except for those explicitly requested to be kept.
The models will be checked by lavaan
to make sure that the increase in
model degrees of freedom is of the
expected value.
This function is called by
model_set() and usually users do
not need to call it. It is exported
for advanced users.
print.partables()
library(lavaan)
dat <- dat_path_model
mod <-
"
x3 ~ a*x1 + b*x2
x4 ~ a*x1 + x2
ab := a*b
"
fit <- sem(mod, dat_path_model, fixed.x = TRUE)
mod_to_drop <- get_drop(fit)
mod_to_drop
Run the code above in your browser using DataLab