Learn R Programming

modelbpp (version 0.2.0)

modelbpp-package: modelbpp: Model BIC Posterior Probability

Description

logo

Fits the neighboring models of a fitted structural equation model and assesses the model uncertainty of the fitted model based on BIC posterior probabilities (BPP), using the method presented in Wu, Cheung, and Leung (2020) tools:::Rd_expr_doi("10.1080/00273171.2019.1574546"). See Pesigan, Cheung, Wu, Chang, and Leung (2026) tools:::Rd_expr_doi("10.3758/s13428-025-02921-x") for an introduction to the package.

Arguments

Author

Maintainer: Shu Fai Cheung shufai.cheung@gmail.com (ORCID)

Authors:

  • Huiping Wu

  • Shing On Leung (ORCID)

Other contributors:

See Also